Class: TestCentricity::PageSection
- Includes:
- Capybara::DSL, Capybara::Node::Matchers, Test::Unit::Assertions
- Defined in:
- lib/testcentricity_web/page_sections_helper.rb
Instance Attribute Summary collapse
-
#context ⇒ Object
readonly
Returns the value of attribute context.
-
#list_index ⇒ Object
Returns the value of attribute list_index.
-
#locator ⇒ Object
Returns the value of attribute locator.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#parent ⇒ Object
Returns the value of attribute parent.
-
#parent_list ⇒ Object
Returns the value of attribute parent_list.
Class Method Summary collapse
-
.button(element_name, locator) ⇒ Object
Declare and instantiate a single button UI Element for this page section.
-
.buttons(element_hash) ⇒ Object
Declare and instantiate a collection of buttons for this page section.
-
.cell_button(element_name, locator, table, column) ⇒ Object
Declare and instantiate a cell button in a table column on this page section.
-
.cell_checkbox(element_name, locator, table, column, proxy = nil) ⇒ Object
Declare and instantiate a cell checkbox in a table column on this page section.
-
.cell_radio(element_name, locator, table, column, proxy = nil) ⇒ Object
Declare and instantiate a cell radio in a table column on this page section.
-
.checkbox(element_name, locator, proxy = nil) ⇒ Object
Declare and instantiate a single checkbox UI Element for this page section.
-
.checkboxes(element_hash) ⇒ Object
Declare and instantiate a collection of checkboxes for this page section.
-
.element(element_name, locator) ⇒ Object
Declare and instantiate a single generic UI Element for this page section.
-
.elements(element_hash) ⇒ Object
Declare and instantiate a collection of generic UI Elements for this page section.
-
.filefield(element_name, locator) ⇒ Object
Declare and instantiate a single File Field UI Element for this page section.
- .filefields(element_hash) ⇒ Object
-
.image(element_name, locator) ⇒ Object
Declare and instantiate an single image UI Element for this page section.
- .images(element_hash) ⇒ Object
-
.label(element_name, locator) ⇒ Object
Declare and instantiate a single label UI Element for this page section.
- .labels(element_hash) ⇒ Object
-
.link(element_name, locator) ⇒ Object
Declare and instantiate a single link UI Element for this page section.
- .links(element_hash) ⇒ Object
-
.list(element_name, locator) ⇒ Object
Declare and instantiate a single list UI Element for this page section.
-
.list_button(element_name, locator, list) ⇒ Object
Declare and instantiate a list button in a row of a list object on this section object.
-
.list_checkbox(element_name, locator, list, proxy = nil) ⇒ Object
Declare and instantiate a list checkbox in a row of a list object on this section object.
-
.list_radio(element_name, locator, list, proxy = nil) ⇒ Object
Declare and instantiate a list radio in a row of a list object on this section object.
- .lists(element_hash) ⇒ Object
-
.radio(element_name, locator, proxy = nil) ⇒ Object
Declare and instantiate a single radio button UI Element for this page section.
-
.radios(element_hash) ⇒ Object
Declare and instantiate a collection of radio buttons for this page section.
-
.section(section_name, class_name, locator = nil) ⇒ Object
Instantiate a single PageSection object within this PageSection object.
- .sections(section_hash) ⇒ Object
-
.selectlist(element_name, locator) ⇒ Object
Declare and instantiate a single select list UI Element for this page section.
- .selectlists(element_hash) ⇒ Object
-
.table(element_name, locator) ⇒ Object
Declare and instantiate a single table UI Element for this page section.
- .tables(element_hash) ⇒ Object
-
.textfield(element_name, locator) ⇒ Object
Declare and instantiate a single text field UI Element for this page section.
-
.textfields(element_hash) ⇒ Object
Declare and instantiate a collection of text fields for this page section.
-
.trait(trait_name, &block) ⇒ Object
Define a trait for this page section.
Instance Method Summary collapse
-
#click_at(x, y) ⇒ Object
Click at a specific location within a Section object.
-
#disabled? ⇒ Boolean
Is Section object disabled (not enabled)?.
-
#enabled? ⇒ Boolean
Is Section object enabled?.
-
#exists? ⇒ Boolean
Does Section object exists?.
- #get_attribute(attrib) ⇒ Object
- #get_item_count ⇒ Object
- #get_list_items ⇒ Object
- #get_locator ⇒ Object
- #get_name ⇒ Object
- #get_native_attribute(attrib) ⇒ Object
- #get_object_type ⇒ Object
-
#hidden? ⇒ Boolean
Is Section object hidden (not visible)?.
-
#initialize(name, parent, locator, context) ⇒ PageSection
constructor
A new instance of PageSection.
-
#populate_data_fields(data) ⇒ Object
Populate the specified UI elements in this Section object with the associated data from a Hash passed as an argument.
- #set_list_index(list, index = 1) ⇒ Object
- #set_parent(parent) ⇒ Object
- #verify_ui_states(ui_states) ⇒ Object
-
#visible? ⇒ Boolean
Is Section object visible?.
-
#wait_until_exists(seconds = nil) ⇒ Object
Wait until the Section object exists, or until the specified wait time has expired.
-
#wait_until_gone(seconds = nil) ⇒ Object
Wait until the Section object no longer exists, or until the specified wait time has expired.
-
#wait_until_hidden(seconds = nil) ⇒ Object
Wait until the Section object is hidden, or until the specified wait time has expired.
-
#wait_until_visible(seconds = nil) ⇒ Object
Wait until the Section object is visible, or until the specified wait time has expired.
Constructor Details
#initialize(name, parent, locator, context) ⇒ PageSection
Returns a new instance of PageSection.
16 17 18 19 20 21 22 23 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 16 def initialize(name, parent, locator, context) @name = name @parent = parent @locator = locator @context = context @parent_list = nil @list_index = nil end |
Instance Attribute Details
#context ⇒ Object (readonly)
Returns the value of attribute context.
9 10 11 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 9 def context @context end |
#list_index ⇒ Object
Returns the value of attribute list_index.
13 14 15 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 13 def list_index @list_index end |
#locator ⇒ Object
Returns the value of attribute locator.
10 11 12 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 10 def locator @locator end |
#name ⇒ Object (readonly)
Returns the value of attribute name.
9 10 11 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 9 def name @name end |
#parent ⇒ Object
Returns the value of attribute parent.
11 12 13 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 11 def parent @parent end |
#parent_list ⇒ Object
Returns the value of attribute parent_list.
12 13 14 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 12 def parent_list @parent_list end |
Class Method Details
.button(element_name, locator) ⇒ Object
Declare and instantiate a single button UI Element for this page section.
127 128 129 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 127 def self.(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::Button.new("#{element_name}", self, "#{locator}", :section);end)) end |
.buttons(element_hash) ⇒ Object
Declare and instantiate a collection of buttons for this page section.
139 140 141 142 143 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 139 def self.(element_hash) element_hash.each do |element_name, locator| (element_name, locator) end end |
.cell_button(element_name, locator, table, column) ⇒ Object
Declare and instantiate a cell button in a table column on this page section.
362 363 364 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 362 def self.(element_name, locator, table, column) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::CellButton.new("#{element_name}", self, "#{locator}", :section, #{table}, #{column});end)) end |
.cell_checkbox(element_name, locator, table, column, proxy = nil) ⇒ Object
Declare and instantiate a cell checkbox in a table column on this page section.
375 376 377 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 375 def self.cell_checkbox(element_name, locator, table, column, proxy = nil) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::CellCheckBox.new("#{element_name}", self, "#{locator}", :section, #{table}, #{column}, #{proxy});end)) end |
.cell_radio(element_name, locator, table, column, proxy = nil) ⇒ Object
Declare and instantiate a cell radio in a table column on this page section.
388 389 390 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 388 def self.cell_radio(element_name, locator, table, column, proxy = nil) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::CellRadio.new("#{element_name}", self, "#{locator}", :section, #{table}, #{column}, #{proxy});end)) end |
.checkbox(element_name, locator, proxy = nil) ⇒ Object
Declare and instantiate a single checkbox UI Element for this page section.
182 183 184 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 182 def self.checkbox(element_name, locator, proxy = nil) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::CheckBox.new("#{element_name}", self, "#{locator}", :section, #{proxy});end)) end |
.checkboxes(element_hash) ⇒ Object
Declare and instantiate a collection of checkboxes for this page section.
195 196 197 198 199 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 195 def self.checkboxes(element_hash) element_hash.each do |element_name, locator| checkbox(element_name, locator) end end |
.element(element_name, locator) ⇒ Object
Declare and instantiate a single generic UI Element for this page section.
101 102 103 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 101 def self.element(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::UIElement.new("#{element_name}", self, "#{locator}", :section);end)) end |
.elements(element_hash) ⇒ Object
Declare and instantiate a collection of generic UI Elements for this page section.
113 114 115 116 117 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 113 def self.elements(element_hash) element_hash.each do |element_name, locator| element(element_name, locator) end end |
.filefield(element_name, locator) ⇒ Object
Declare and instantiate a single File Field UI Element for this page section.
342 343 344 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 342 def self.filefield(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::FileField.new("#{element_name}", self, "#{locator}", :section);end)) end |
.filefields(element_hash) ⇒ Object
346 347 348 349 350 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 346 def self.filefields(element_hash) element_hash.each do |element_name, locator| filefield(element_name, locator) end end |
.image(element_name, locator) ⇒ Object
Declare and instantiate an single image UI Element for this page section.
325 326 327 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 325 def self.image(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::Image.new("#{element_name}", self, "#{locator}", :section);end)) end |
.images(element_hash) ⇒ Object
329 330 331 332 333 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 329 def self.images(element_hash) element_hash.each do |element_name, locator| image(element_name, locator) end end |
.label(element_name, locator) ⇒ Object
Declare and instantiate a single label UI Element for this page section.
237 238 239 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 237 def self.label(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::Label.new("#{element_name}", self, "#{locator}", :section);end)) end |
.labels(element_hash) ⇒ Object
241 242 243 244 245 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 241 def self.labels(element_hash) element_hash.each do |element_name, locator| label(element_name, locator) end end |
.link(element_name, locator) ⇒ Object
Declare and instantiate a single link UI Element for this page section.
255 256 257 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 255 def self.link(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::Link.new("#{element_name}", self, "#{locator}", :section);end)) end |
.links(element_hash) ⇒ Object
259 260 261 262 263 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 259 def self.links(element_hash) element_hash.each do |element_name, locator| link(element_name, locator) end end |
.list(element_name, locator) ⇒ Object
Declare and instantiate a single list UI Element for this page section.
307 308 309 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 307 def self.list(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::List.new("#{element_name}", self, "#{locator}", :section);end)) end |
.list_button(element_name, locator, list) ⇒ Object
Declare and instantiate a list button in a row of a list object on this section object.
401 402 403 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 401 def self.(element_name, locator, list) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::ListButton.new("#{element_name}", self, "#{locator}", :section, #{list});end)) end |
.list_checkbox(element_name, locator, list, proxy = nil) ⇒ Object
Declare and instantiate a list checkbox in a row of a list object on this section object.
413 414 415 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 413 def self.list_checkbox(element_name, locator, list, proxy = nil) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::ListCheckBox.new("#{element_name}", self, "#{locator}", :section, #{list}, #{proxy});end)) end |
.list_radio(element_name, locator, list, proxy = nil) ⇒ Object
Declare and instantiate a list radio in a row of a list object on this section object.
425 426 427 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 425 def self.list_radio(element_name, locator, list, proxy = nil) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::CellRadio.new("#{element_name}", self, "#{locator}", :section, #{list}, #{proxy});end)) end |
.lists(element_hash) ⇒ Object
311 312 313 314 315 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 311 def self.lists(element_hash) element_hash.each do |element_name, locator| list(element_name, locator) end end |
.radio(element_name, locator, proxy = nil) ⇒ Object
Declare and instantiate a single radio button UI Element for this page section.
210 211 212 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 210 def self.radio(element_name, locator, proxy = nil) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::Radio.new("#{element_name}", self, "#{locator}", :section, #{proxy});end)) end |
.radios(element_hash) ⇒ Object
Declare and instantiate a collection of radio buttons for this page section.
223 224 225 226 227 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 223 def self.radios(element_hash) element_hash.each do |element_name, locator| radio(element_name, locator) end end |
.section(section_name, class_name, locator = nil) ⇒ Object
Instantiate a single PageSection object within this PageSection object.
436 437 438 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 436 def self.section(section_name, class_name, locator = nil) class_eval(%(def #{section_name};@#{section_name} ||= #{class_name}.new("#{section_name}", self, "#{locator}", :section);end)) end |
.sections(section_hash) ⇒ Object
440 441 442 443 444 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 440 def self.sections(section_hash) section_hash.each do |section_name, class_name| section(section_name, class_name) end end |
.selectlist(element_name, locator) ⇒ Object
Declare and instantiate a single select list UI Element for this page section.
290 291 292 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 290 def self.selectlist(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::SelectList.new("#{element_name}", self, "#{locator}", :section);end)) end |
.selectlists(element_hash) ⇒ Object
294 295 296 297 298 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 294 def self.selectlists(element_hash) element_hash.each do |element_name, locator| selectlist(element_name, locator) end end |
.table(element_name, locator) ⇒ Object
Declare and instantiate a single table UI Element for this page section.
272 273 274 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 272 def self.table(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::Table.new("#{element_name}", self, "#{locator}", :section);end)) end |
.tables(element_hash) ⇒ Object
276 277 278 279 280 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 276 def self.tables(element_hash) element_hash.each do |element_name, locator| table(element_name, locator) end end |
.textfield(element_name, locator) ⇒ Object
Declare and instantiate a single text field UI Element for this page section.
153 154 155 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 153 def self.textfield(element_name, locator) class_eval(%(def #{element_name};@#{element_name} ||= TestCentricity::TextField.new("#{element_name}", self, "#{locator}", :section);end)) end |
.textfields(element_hash) ⇒ Object
Declare and instantiate a collection of text fields for this page section.
167 168 169 170 171 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 167 def self.textfields(element_hash) element_hash.each do |element_name, locator| textfield(element_name, locator) end end |
.trait(trait_name, &block) ⇒ Object
Define a trait for this page section.
89 90 91 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 89 def self.trait(trait_name, &block) define_method(trait_name.to_s, &block) end |
Instance Method Details
#click_at(x, y) ⇒ Object
Click at a specific location within a Section object
567 568 569 570 571 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 567 def click_at(x, y) section, = find_section raise "Section object '#{get_name}' (#{get_locator}) not found" unless section section.click_at(x, y) end |
#disabled? ⇒ Boolean
Is Section object disabled (not enabled)?
473 474 475 476 477 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 473 def disabled? obj, = find_element object_not_found_exception(obj, nil) obj.disabled? end |
#enabled? ⇒ Boolean
Is Section object enabled?
463 464 465 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 463 def enabled? !disabled? end |
#exists? ⇒ Boolean
Does Section object exists?
452 453 454 455 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 452 def exists? section, = find_section section != nil end |
#get_attribute(attrib) ⇒ Object
746 747 748 749 750 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 746 def get_attribute(attrib) section, = find_section raise "Section object '#{get_name}' (#{get_locator}) not found" unless section section[attrib] end |
#get_item_count ⇒ Object
55 56 57 58 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 55 def get_item_count raise 'No parent list defined' if @parent_list.nil? @parent_list.get_item_count end |
#get_list_items ⇒ Object
60 61 62 63 64 65 66 67 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 60 def get_list_items items = [] (1..get_item_count).each do |item| set_list_index(nil, item) items.push(get_value) end items end |
#get_locator ⇒ Object
25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 25 def get_locator if @locator.empty? && defined?(section_locator) locator = section_locator else locator = @locator end unless @parent_list.nil? locator = "#{@parent_list.get_locator}|#{locator}" unless @list_index.nil? if locator.include?('/') locator = "(#{locator})[#{@list_index}]" else locator = "#{locator}:nth-of-type(#{@list_index})" end end end if @context == :section && !@parent.nil? && !@parent.get_locator.nil? "#{@parent.get_locator}|#{locator}" else locator end end |
#get_name ⇒ Object
73 74 75 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 73 def get_name @name end |
#get_native_attribute(attrib) ⇒ Object
752 753 754 755 756 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 752 def get_native_attribute(attrib) section, = find_section raise "Section object '#{get_name}' (#{get_locator}) not found" unless section section.native.attribute(attrib) end |
#get_object_type ⇒ Object
69 70 71 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 69 def get_object_type :section end |
#hidden? ⇒ Boolean
Is Section object hidden (not visible)?
500 501 502 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 500 def hidden? !visible? end |
#populate_data_fields(data) ⇒ Object
Populate the specified UI elements in this Section object with the associated data from a Hash passed as an argument. Data values must be in the form of a String for textfield and select list controls. For checkbox and radio buttons, data must either be a Boolean or a String that evaluates to a Boolean value (Yes, No, 1, 0, true, false)
719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 719 def populate_data_fields(data) data.each do |data_field, data_param| unless data_param.blank? # make sure the intended UI target element exists before trying to set its value data_field.wait_until_exists(2) if data_param == '!DELETE' data_field.set('') else case data_field.get_object_type when :checkbox data_field.set_checkbox_state(data_param.to_bool) when :selectlist data_field.get_siebel_object_type == 'JComboBox' ? data_field.set("#{data_param}\t") : data_field.choose_option(data_param) when :radio data_field.set_selected_state(data_param.to_bool) when :textfield data_field.set("#{data_param}\t") when :section data_field.set(data_param) end end end end end |
#set_list_index(list, index = 1) ⇒ Object
50 51 52 53 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 50 def set_list_index(list, index = 1) @parent_list = list unless list.nil? @list_index = index end |
#set_parent(parent) ⇒ Object
77 78 79 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 77 def set_parent(parent) @parent = parent end |
#verify_ui_states(ui_states) ⇒ Object
573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 573 def verify_ui_states(ui_states) ui_states.each do |ui_object, object_states| object_states.each do |property, state| case property when :class actual = ui_object.get_attribute(:class) when :exists actual = ui_object.exists? when :enabled actual = ui_object.enabled? when :disabled actual = ui_object.disabled? when :visible actual = ui_object.visible? when :hidden actual = ui_object.hidden? when :width actual = ui_object.get_width when :height actual = ui_object.get_height when :readonly actual = ui_object.read_only? when :checked actual = ui_object.checked? when :selected actual = ui_object.selected? when :value, :caption actual = ui_object.get_value when :maxlength actual = ui_object.get_max_length when :rowcount actual = ui_object.get_row_count when :columncount actual = ui_object.get_column_count when :placeholder actual = ui_object.get_placeholder when :options, :items, :list_items actual = ui_object.get_list_items when :optioncount, :itemcount actual = ui_object.get_item_count when :column_headers actual = ui_object.get_header_columns when :siebel_options actual = ui_object. else if property.is_a?(Hash) property.each do |key, value| case key when :cell actual = ui_object.get_table_cell(value[0].to_i, value[1].to_i) when :row actual = ui_object.get_table_row(value.to_i) when :column actual = ui_object.get_table_column(value.to_i) when :item actual = ui_object.get_list_item(value.to_i) when :attribute actual = ui_object.get_attribute(value) when :native_attribute actual = ui_object.get_native_attribute(value) end end else props = property.to_s.split('_') case props[0].to_sym when :cell cell = property.to_s.delete('cell_') cell = cell.split('_') actual = ui_object.get_table_cell(cell[0].to_i, cell[1].to_i) when :row row = property.to_s.delete('row_') actual = ui_object.get_table_row(row.to_i) when :column column = property.to_s.delete('column_') actual = ui_object.get_table_column(column.to_i) when :item item = property.to_s.delete('item_') actual = ui_object.get_list_item(item.to_i) end end end if state.is_a?(Hash) && state.length == 1 error_msg = "Expected UI object '#{ui_object.get_name}' (#{ui_object.get_locator}) #{property} property to" state.each do |key, value| case key when :lt, :less_than ExceptionQueue.enqueue_exception("#{error_msg} be less than #{value} but found '#{actual}'") unless actual < value when :lt_eq, :less_than_or_equal ExceptionQueue.enqueue_exception("#{error_msg} be less than or equal to #{value} but found '#{actual}'") unless actual <= value when :gt, :greater_than ExceptionQueue.enqueue_exception("#{error_msg} be greater than #{value} but found '#{actual}'") unless actual > value when :gt_eq, :greater_than_or_equal ExceptionQueue.enqueue_exception("#{error_msg} be greater than or equal to #{value} but found '#{actual}'") unless actual >= value when :starts_with ExceptionQueue.enqueue_exception("#{error_msg} start with '#{value}' but found '#{actual}'") unless actual.start_with?(value) when :ends_with ExceptionQueue.enqueue_exception("#{error_msg} end with '#{value}' but found '#{actual}'") unless actual.end_with?(value) when :contains ExceptionQueue.enqueue_exception("#{error_msg} contain '#{value}' but found '#{actual}'") unless actual.include?(value) when :not_contains, :does_not_contain ExceptionQueue.enqueue_exception("#{error_msg} not contain '#{value}' but found '#{actual}'") if actual.include?(value) when :not_equal ExceptionQueue.enqueue_exception("#{error_msg} not equal '#{value}' but found '#{actual}'") if actual == value when :like, :is_like actual_like = actual.delete("\n") actual_like = actual_like.delete("\r") actual_like = actual_like.delete("\t") actual_like = actual_like.delete(' ') actual_like = actual_like.downcase expected = value.delete("\n") expected = expected.delete("\r") expected = expected.delete("\t") expected = expected.delete(' ') expected = expected.downcase ExceptionQueue.enqueue_exception("#{error_msg} be like '#{value}' but found '#{actual}'") unless actual_like.include?(expected) when :translate expected = I18n.t(value) ExceptionQueue.enqueue_assert_equal(expected, actual, "Expected UI object '#{ui_object.get_name}' (#{ui_object.get_locator}) translated #{property} property") end end else ExceptionQueue.enqueue_assert_equal(state, actual, "Expected UI object '#{ui_object.get_name}' (#{ui_object.get_locator}) #{property} property") end end end ExceptionQueue.post_exceptions end |
#visible? ⇒ Boolean
Is Section object visible?
485 486 487 488 489 490 491 492 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 485 def visible? section, = find_section exists = section visible = false visible = section.visible? if exists # the section is visible if it exists and it is not invisible exists && visible ? true : false end |
#wait_until_exists(seconds = nil) ⇒ Object
Wait until the Section object exists, or until the specified wait time has expired.
510 511 512 513 514 515 516 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 510 def wait_until_exists(seconds = nil) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { exists? } rescue raise "Could not find Section object '#{get_name}' (#{get_locator}) after #{timeout} seconds" unless exists? end |
#wait_until_gone(seconds = nil) ⇒ Object
Wait until the Section object no longer exists, or until the specified wait time has expired.
524 525 526 527 528 529 530 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 524 def wait_until_gone(seconds = nil) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { !exists? } rescue raise "Section object '#{get_name}' (#{get_locator}) remained visible after #{timeout} seconds" if exists? end |
#wait_until_hidden(seconds = nil) ⇒ Object
Wait until the Section object is hidden, or until the specified wait time has expired.
552 553 554 555 556 557 558 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 552 def wait_until_hidden(seconds = nil) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { hidden? } rescue raise "Section object '#{get_name}' (#{get_locator}) remained visible after #{timeout} seconds" if visible? end |
#wait_until_visible(seconds = nil) ⇒ Object
Wait until the Section object is visible, or until the specified wait time has expired.
538 539 540 541 542 543 544 |
# File 'lib/testcentricity_web/page_sections_helper.rb', line 538 def wait_until_visible(seconds = nil) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { visible? } rescue raise "Could not find Section object '#{get_name}' (#{get_locator}) after #{timeout} seconds" unless visible? end |