Class: TestCentricity::UIElement
- Includes:
- Capybara::DSL, Test::Unit::Assertions
- Defined in:
- lib/testcentricity_web/web_elements/ui_elements_helper.rb,
lib/testcentricity_web/web_elements/siebel_open_ui_helper.rb
Direct Known Subclasses
Button, CellElement, CheckBox, FileField, Image, Label, Link, List, ListElement, Media, Radio, SelectList, Table, TextField
Constant Summary collapse
- XPATH_SELECTORS =
['//', '[@', '[contains(']
- CSS_SELECTORS =
['#', ':nth-child(', ':first-child', ':last-child', ':nth-of-type(', ':first-of-type', ':last-of-type', '^=', '$=', '*=', ':contains(']
Instance Attribute Summary collapse
-
#alt_locator ⇒ Object
Returns the value of attribute alt_locator.
-
#context ⇒ Object
readonly
Returns the value of attribute context.
-
#locator ⇒ Object
readonly
Returns the value of attribute locator.
-
#locator_type ⇒ Object
Returns the value of attribute locator_type.
-
#name ⇒ Object
readonly
Returns the value of attribute name.
-
#original_style ⇒ Object
Returns the value of attribute original_style.
-
#parent ⇒ Object
readonly
Returns the value of attribute parent.
-
#type ⇒ Object
readonly
Returns the value of attribute type.
Instance Method Summary collapse
-
#aria_autocomplete ⇒ Integer
Return state of UI object's aria-autocomplete property.
-
#aria_busy? ⇒ Boolean
Return state of UI object's aria-busy property.
-
#aria_checked? ⇒ Boolean
Return state of UI object's aria-checked property.
-
#aria_colcount ⇒ Integer
Return state of UI object's aria-colcount property.
-
#aria_controls ⇒ Integer
Return state of UI object's aria-controls property.
-
#aria_describedby ⇒ String
Return state of UI object's aria-describedby property.
-
#aria_disabled? ⇒ Boolean
Return state of UI object's aria-disabled property.
-
#aria_expanded? ⇒ Boolean
Return state of UI object's aria-expanded property.
-
#aria_haspopup? ⇒ Boolean
Return state of UI object's aria-haspopup property.
-
#aria_hidden? ⇒ Boolean
Return state of UI object's aria-hidden property.
-
#aria_invalid? ⇒ Boolean
Return state of UI object's aria-invalid property.
-
#aria_keyshortcuts ⇒ Integer
Return state of UI object's aria-keyshortcuts property.
-
#aria_label ⇒ String
Return state of UI object's aria-label property.
-
#aria_labelledby ⇒ String
Return state of UI object's aria-labelledby property.
-
#aria_live ⇒ String
Return state of UI object's aria-live property.
-
#aria_modal? ⇒ Boolean
Return state of UI object's aria-modal property.
-
#aria_multiline? ⇒ Boolean
Return state of UI object's aria-multiline property.
-
#aria_multiselectable? ⇒ Boolean
Return state of UI object's aria-multiselectable property.
-
#aria_orientation ⇒ Integer
Return state of UI object's aria-orientation property.
-
#aria_pressed? ⇒ Boolean
Return state of UI object's aria-pressed property.
-
#aria_readonly? ⇒ Boolean
Return state of UI object's aria-readonly property.
-
#aria_required? ⇒ Boolean
Return state of UI object's aria-required property.
-
#aria_roledescription ⇒ Integer
Return state of UI object's aria-roledescription property.
-
#aria_rowcount ⇒ Integer
Return state of UI object's aria-rowcount property.
-
#aria_selected? ⇒ Boolean
Return state of UI object's aria-selected property.
-
#aria_sort ⇒ String
Return state of UI object's aria-sort property.
-
#aria_valuemax ⇒ Integer
Return state of UI object's aria-valuemax property.
-
#aria_valuemin ⇒ Integer
Return state of UI object's aria-valuemin property.
-
#aria_valuenow ⇒ Integer
Return state of UI object's aria-valuenow property.
-
#aria_valuetext ⇒ Integer
Return state of UI object's aria-valuetext property.
- #clear_alt_locator ⇒ Object
-
#click ⇒ Object
Click on an object.
-
#click_at(x, y) ⇒ Object
Click at a specific location within an object.
-
#content_editable? ⇒ Boolean
Return state of UI object's contenteditable property.
-
#count(visible = true) ⇒ Object
Return the number of occurrences of an object with an ambiguous locator that evaluates to multiple UI elements.
-
#disabled? ⇒ Boolean
Is UI object disabled (not enabled)?.
-
#displayed? ⇒ Boolean
Is UI object displayed in browser window?.
-
#double_click ⇒ Object
Double-click on an object.
- #drag_and_drop(target, right_offset = nil, down_offset = nil) ⇒ Object
- #drag_by(right_offset, down_offset) ⇒ Object
-
#enabled? ⇒ Boolean
Is UI object enabled?.
-
#exists?(visible = true) ⇒ Boolean
Does UI object exists?.
- #get_attribute(attrib) ⇒ Object
- #get_locator ⇒ Object
- #get_locator_type ⇒ Object
- #get_name ⇒ Object
- #get_native_attribute(attrib) ⇒ Object
- #get_object_type ⇒ Object
- #get_siebel_object_type ⇒ Object
- #get_value(visible = true) ⇒ Object (also: #get_caption)
-
#height ⇒ Integer
Return height of object.
-
#hidden? ⇒ Boolean
Is UI object hidden (not visible)?.
-
#highlight(duration = 1) ⇒ Object
Highlight an object with a 3 pixel wide, red dashed border for the specified wait time.
-
#hover ⇒ Object
Hover the cursor over an object.
-
#hover_at(x, y) ⇒ Object
Hover at a specific location within an object.
-
#initialize(name, parent, locator, context) ⇒ UIElement
constructor
A new instance of UIElement.
-
#inspect ⇒ String
Return a human readable representation of the UI element.
- #invoke_siebel_dialog(popup, seconds = nil) ⇒ Object
-
#obscured? ⇒ Boolean
Is UI object obscured (not currently in viewport and not clickable)?.
-
#right_click ⇒ Object
Right-click on an object.
-
#role ⇒ String
Return state of UI object's role property.
-
#send_keys(*keys) ⇒ Object
Send keystrokes to this object.
- #set(value) ⇒ Object
- #set_alt_locator(temp_locator) ⇒ Object
- #set_locator_type(locator = nil) ⇒ Object
-
#style ⇒ String
Return UI object's style property.
-
#tabindex ⇒ String
Return state of UI object's tabindex property.
-
#title ⇒ String
Return UI object's title property.
-
#unhighlight ⇒ Object
Restore a highlighted object's original style.
- #verify_value(expected, enqueue = false) ⇒ Object (also: #verify_caption)
-
#visible? ⇒ Boolean
Is UI object visible?.
-
#wait_until_exists(seconds = nil, post_exception = true) ⇒ Object
Wait until the object exists, or until the specified wait time has expired.
-
#wait_until_gone(seconds = nil, post_exception = true) ⇒ Object
Wait until the object no longer exists, or until the specified wait time has expired.
-
#wait_until_hidden(seconds = nil, post_exception = true) ⇒ Object
Wait until the object is hidden, or until the specified wait time has expired.
-
#wait_until_value_changes(seconds = nil, post_exception = true) ⇒ Object
Wait until the object's value changes to a different value, or until the specified wait time has expired.
-
#wait_until_value_is(value, seconds = nil, post_exception = true) ⇒ Object
Wait until the object's value equals the specified value, or until the specified wait time has expired.
-
#wait_until_visible(seconds = nil, post_exception = true) ⇒ Object
Wait until the object is visible, or until the specified wait time has expired.
-
#width ⇒ Integer
Return width of object.
-
#x ⇒ Integer
Return x coordinate of object's location.
-
#y ⇒ Integer
Return y coordinate of object's location.
Constructor Details
#initialize(name, parent, locator, context) ⇒ UIElement
Returns a new instance of UIElement.
51 52 53 54 55 56 57 58 59 60 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 51 def initialize(name, parent, locator, context) @name = name @parent = parent @locator = locator @context = context @type = nil @alt_locator = nil @original_style = nil set_locator_type end |
Instance Attribute Details
#alt_locator ⇒ Object
Returns the value of attribute alt_locator.
46 47 48 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 46 def alt_locator @alt_locator end |
#context ⇒ Object (readonly)
Returns the value of attribute context.
45 46 47 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 45 def context @context end |
#locator ⇒ Object (readonly)
Returns the value of attribute locator.
45 46 47 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 45 def locator @locator end |
#locator_type ⇒ Object
Returns the value of attribute locator_type.
46 47 48 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 46 def locator_type @locator_type end |
#name ⇒ Object (readonly)
Returns the value of attribute name.
45 46 47 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 45 def name @name end |
#original_style ⇒ Object
Returns the value of attribute original_style.
46 47 48 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 46 def original_style @original_style end |
#parent ⇒ Object (readonly)
Returns the value of attribute parent.
45 46 47 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 45 def parent @parent end |
#type ⇒ Object (readonly)
Returns the value of attribute type.
45 46 47 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 45 def type @type end |
Instance Method Details
#aria_autocomplete ⇒ Integer
Return state of UI object's aria-autocomplete property
749 750 751 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 749 def aria_autocomplete get_attribute('aria-autocomplete') end |
#aria_busy? ⇒ Boolean
Return state of UI object's aria-busy property
879 880 881 882 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 879 def aria_busy? state = get_attribute('aria-busy') state.boolean? ? state : state == 'true' end |
#aria_checked? ⇒ Boolean
Return state of UI object's aria-checked property
835 836 837 838 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 835 def aria_checked? state = get_attribute('aria-checked') state.boolean? ? state : state == 'true' end |
#aria_colcount ⇒ Integer
Return state of UI object's aria-colcount property
669 670 671 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 669 def aria_colcount get_attribute('aria-colcount') end |
#aria_controls ⇒ Integer
Return state of UI object's aria-controls property
759 760 761 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 759 def aria_controls get_attribute('aria-controls') end |
#aria_describedby ⇒ String
Return state of UI object's aria-describedby property
629 630 631 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 629 def aria_describedby get_attribute('aria-describedby') end |
#aria_disabled? ⇒ Boolean
Return state of UI object's aria-disabled property
769 770 771 772 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 769 def aria_disabled? state = get_attribute('aria-disabled') state.boolean? ? state : state == 'true' end |
#aria_expanded? ⇒ Boolean
Return state of UI object's aria-expanded property
802 803 804 805 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 802 def state = get_attribute('aria-expanded') state.boolean? ? state : state == 'true' end |
#aria_haspopup? ⇒ Boolean
Return state of UI object's aria-haspopup property
846 847 848 849 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 846 def aria_haspopup? state = get_attribute('aria-haspopup') state.boolean? ? state : state == 'true' end |
#aria_hidden? ⇒ Boolean
Return state of UI object's aria-hidden property
791 792 793 794 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 791 def aria_hidden? state = get_attribute('aria-hidden') state.boolean? ? state : state == 'true' end |
#aria_invalid? ⇒ Boolean
Return state of UI object's aria-invalid property
824 825 826 827 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 824 def aria_invalid? state = get_attribute('aria-invalid') state.boolean? ? state : state == 'true' end |
#aria_keyshortcuts ⇒ Integer
Return state of UI object's aria-keyshortcuts property
729 730 731 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 729 def aria_keyshortcuts get_attribute('aria-keyshortcuts') end |
#aria_label ⇒ String
Return state of UI object's aria-label property
609 610 611 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 609 def aria_label get_attribute('aria-label') end |
#aria_labelledby ⇒ String
Return state of UI object's aria-labelledby property
619 620 621 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 619 def aria_labelledby get_attribute('aria-labelledby') end |
#aria_live ⇒ String
Return state of UI object's aria-live property
639 640 641 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 639 def aria_live get_attribute('aria-live') end |
#aria_modal? ⇒ Boolean
Return state of UI object's aria-modal property
890 891 892 893 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 890 def aria_modal? state = get_attribute('aria-modal') state.boolean? ? state : state == 'true' end |
#aria_multiline? ⇒ Boolean
Return state of UI object's aria-multiline property
901 902 903 904 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 901 def aria_multiline? state = get_attribute('aria-multiline') state.boolean? ? state : state == 'true' end |
#aria_multiselectable? ⇒ Boolean
Return state of UI object's aria-multiselectable property
912 913 914 915 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 912 def aria_multiselectable? state = get_attribute('aria-multiselectable') state.boolean? ? state : state == 'true' end |
#aria_orientation ⇒ Integer
Return state of UI object's aria-orientation property
719 720 721 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 719 def aria_orientation get_attribute('aria-orientation') end |
#aria_pressed? ⇒ Boolean
Return state of UI object's aria-pressed property
857 858 859 860 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 857 def aria_pressed? state = get_attribute('aria-pressed') state.boolean? ? state : state == 'true' end |
#aria_readonly? ⇒ Boolean
Return state of UI object's aria-readonly property
868 869 870 871 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 868 def aria_readonly? state = get_attribute('aria-readonly') state.boolean? ? state : state == 'true' end |
#aria_required? ⇒ Boolean
Return state of UI object's aria-required property
813 814 815 816 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 813 def aria_required? state = get_attribute('aria-required') state.boolean? ? state : state == 'true' end |
#aria_roledescription ⇒ Integer
Return state of UI object's aria-roledescription property
739 740 741 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 739 def aria_roledescription get_attribute('aria-roledescription') end |
#aria_rowcount ⇒ Integer
Return state of UI object's aria-rowcount property
659 660 661 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 659 def aria_rowcount get_attribute('aria-rowcount') end |
#aria_selected? ⇒ Boolean
Return state of UI object's aria-selected property
780 781 782 783 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 780 def aria_selected? state = get_attribute('aria-selected') state.boolean? ? state : state == 'true' end |
#aria_sort ⇒ String
Return state of UI object's aria-sort property
649 650 651 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 649 def aria_sort get_attribute('aria-sort') end |
#aria_valuemax ⇒ Integer
Return state of UI object's aria-valuemax property
679 680 681 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 679 def aria_valuemax get_attribute('aria-valuemax') end |
#aria_valuemin ⇒ Integer
Return state of UI object's aria-valuemin property
689 690 691 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 689 def aria_valuemin get_attribute('aria-valuemin') end |
#aria_valuenow ⇒ Integer
Return state of UI object's aria-valuenow property
699 700 701 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 699 def aria_valuenow get_attribute('aria-valuenow') end |
#aria_valuetext ⇒ Integer
Return state of UI object's aria-valuetext property
709 710 711 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 709 def aria_valuetext get_attribute('aria-valuetext') end |
#clear_alt_locator ⇒ Object
107 108 109 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 107 def clear_alt_locator @alt_locator = nil end |
#click ⇒ Object
Click on an object
116 117 118 119 120 121 122 123 124 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 116 def click obj, type = find_element object_not_found_exception(obj, type) begin obj.click rescue StandardError obj.click_at(10, 10) end end |
#click_at(x, y) ⇒ Object
Click at a specific location within an object
155 156 157 158 159 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 155 def click_at(x, y) obj, = find_element raise "UI #{} not found" unless obj obj.click_at(x, y) end |
#content_editable? ⇒ Boolean
Return state of UI object's contenteditable property
923 924 925 926 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 923 def content_editable? state = get_attribute('contenteditable') state.boolean? ? state : state == 'true' end |
#count(visible = true) ⇒ Object
Return the number of occurrences of an object with an ambiguous locator that evaluates to multiple UI elements.
387 388 389 390 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 387 def count(visible = true) obj_locator = @alt_locator.nil? ? @locator : @alt_locator page.all(@locator_type, obj_locator, wait: 0.01, visible: visible, minimum: 0).count end |
#disabled? ⇒ Boolean
Is UI object disabled (not enabled)?
228 229 230 231 232 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 228 def disabled? obj, type = find_element object_not_found_exception(obj, type) obj.disabled? end |
#displayed? ⇒ Boolean
Is UI object displayed in browser window?
456 457 458 459 460 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 456 def displayed? obj, type = find_element(false) object_not_found_exception(obj, type) obj.displayed? end |
#double_click ⇒ Object
Double-click on an object
131 132 133 134 135 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 131 def double_click obj, type = find_element object_not_found_exception(obj, type) page.driver.browser.action.double_click(obj.native).perform end |
#drag_and_drop(target, right_offset = nil, down_offset = nil) ⇒ Object
516 517 518 519 520 521 522 523 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 516 def drag_and_drop(target, right_offset = nil, down_offset = nil) source, type = find_element object_not_found_exception(source, type) page.driver.browser.action.click_and_hold(source.native).perform sleep(1) target_drop, = target.find_element page.driver.browser.action.move_to(target_drop.native, right_offset.to_i, down_offset.to_i).release.perform end |
#drag_by(right_offset, down_offset) ⇒ Object
508 509 510 511 512 513 514 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 508 def drag_by(right_offset, down_offset) obj, type = find_element object_not_found_exception(obj, type) page.driver.browser.action.click_and_hold(obj.native).perform sleep(1) obj.drag_by(right_offset, down_offset) end |
#enabled? ⇒ Boolean
Is UI object enabled?
218 219 220 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 218 def enabled? !disabled? end |
#exists?(visible = true) ⇒ Boolean
Does UI object exists?
185 186 187 188 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 185 def exists?(visible = true) obj, = find_object(visible) obj != nil end |
#get_attribute(attrib) ⇒ Object
928 929 930 931 932 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 928 def get_attribute(attrib) obj, type = find_element(visible = false) object_not_found_exception(obj, type) obj[attrib] end |
#get_locator ⇒ Object
95 96 97 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 95 def get_locator @locator end |
#get_locator_type ⇒ Object
77 78 79 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 77 def get_locator_type @locator_type end |
#get_name ⇒ Object
99 100 101 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 99 def get_name @name end |
#get_native_attribute(attrib) ⇒ Object
934 935 936 937 938 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 934 def get_native_attribute(attrib) obj, type = find_element(visible = false) object_not_found_exception(obj, type) obj.native.attribute(attrib) end |
#get_object_type ⇒ Object
81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 81 def get_object_type if @type @type else obj, type = find_element object_not_found_exception(obj, type) if obj.tag_name obj.tag_name elsif obj.native.attribute('type') obj.native.attribute('type') end end end |
#get_siebel_object_type ⇒ Object
9 10 11 12 13 |
# File 'lib/testcentricity_web/web_elements/siebel_open_ui_helper.rb', line 9 def get_siebel_object_type obj, = find_element object_not_found_exception(obj, 'Siebel object') obj.native.attribute('ot') end |
#get_value(visible = true) ⇒ Object Also known as: get_caption
462 463 464 465 466 467 468 469 470 471 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 462 def get_value(visible = true) obj, type = find_element(visible) object_not_found_exception(obj, type) case obj.tag_name.downcase when 'input', 'select', 'textarea' obj.value else obj.text end end |
#height ⇒ Integer
Return height of object.
410 411 412 413 414 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 410 def height obj, type = find_element(false) object_not_found_exception(obj, type) obj.get_height end |
#hidden? ⇒ Boolean
Is UI object hidden (not visible)?
208 209 210 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 208 def hidden? !visible? end |
#highlight(duration = 1) ⇒ Object
Highlight an object with a 3 pixel wide, red dashed border for the specified wait time. If wait time is zero, then the highlight will remain until the page is refreshed
532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 532 def highlight(duration = 1) obj, type = find_element object_not_found_exception(obj, type) # store original style so it can be reset later @original_style = obj.native.attribute('style') # style element with red border page.execute_script( 'arguments[0].setAttribute(arguments[1], arguments[2])', obj, 'style', 'border: 3px solid red; border-style: dashed;' ) # keep element highlighted for duration and then revert to original style if duration.positive? sleep duration page.execute_script( 'arguments[0].setAttribute(arguments[1], arguments[2])', obj, 'style', @original_style ) end end |
#hover ⇒ Object
Hover the cursor over an object
489 490 491 492 493 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 489 def hover obj, type = find_element object_not_found_exception(obj, type) obj.hover end |
#hover_at(x, y) ⇒ Object
Hover at a specific location within an object
502 503 504 505 506 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 502 def hover_at(x, y) obj, = find_element raise "UI #{} not found" unless obj obj.hover_at(x, y) end |
#inspect ⇒ String
Return a human readable representation of the UI element
252 253 254 255 256 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 252 def inspect obj, type = find_element object_not_found_exception(obj, type) obj.inspect end |
#invoke_siebel_dialog(popup, seconds = nil) ⇒ Object
3 4 5 6 7 |
# File 'lib/testcentricity_web/web_elements/siebel_open_ui_helper.rb', line 3 def invoke_siebel_dialog(popup, seconds = nil) invoke_siebel_popup timeout = seconds.nil? ? 15 : seconds popup.wait_until_exists(timeout) end |
#obscured? ⇒ Boolean
Is UI object obscured (not currently in viewport and not clickable)?
240 241 242 243 244 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 240 def obscured? obj, type = find_element object_not_found_exception(obj, type) obj.obscured? end |
#right_click ⇒ Object
Right-click on an object
142 143 144 145 146 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 142 def right_click obj, type = find_element object_not_found_exception(obj, type) page.driver.browser.action.context_click(obj.native).perform end |
#role ⇒ String
Return state of UI object's role property
589 590 591 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 589 def role get_attribute('role') end |
#send_keys(*keys) ⇒ Object
Send keystrokes to this object.
173 174 175 176 177 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 173 def send_keys(*keys) obj, type = find_element object_not_found_exception(obj, type) obj.send_keys(*keys) end |
#set(value) ⇒ Object
161 162 163 164 165 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 161 def set(value) obj, type = find_element object_not_found_exception(obj, type) obj.set(value) end |
#set_alt_locator(temp_locator) ⇒ Object
103 104 105 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 103 def set_alt_locator(temp_locator) @alt_locator = temp_locator end |
#set_locator_type(locator = nil) ⇒ Object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 62 def set_locator_type(locator = nil) locator = @locator if locator.nil? is_xpath = XPATH_SELECTORS.any? { |selector| locator.include?(selector) } is_css = CSS_SELECTORS.any? { |selector| locator.include?(selector) } @locator_type = if is_xpath && !is_css :xpath elsif is_css && !is_xpath :css elsif !is_css && !is_xpath :css else :css end end |
#style ⇒ String
Return UI object's style property
579 580 581 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 579 def style get_attribute('style') end |
#tabindex ⇒ String
Return state of UI object's tabindex property
599 600 601 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 599 def tabindex get_attribute('tabindex') end |
#title ⇒ String
Return UI object's title property
446 447 448 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 446 def title get_attribute(:title) end |
#unhighlight ⇒ Object
Restore a highlighted object's original style
561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 561 def unhighlight obj, type = find_element object_not_found_exception(obj, type) return if @original_style.nil? page.execute_script( 'arguments[0].setAttribute(arguments[1], arguments[2])', obj, 'style', @original_style ) end |
#verify_value(expected, enqueue = false) ⇒ Object Also known as: verify_caption
475 476 477 478 479 480 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 475 def verify_value(expected, enqueue = false) actual = get_value enqueue ? ExceptionQueue.enqueue_assert_equal(expected.strip, actual.strip, "Expected UI #{}") : assert_equal(expected.strip, actual.strip, "Expected UI #{} to display '#{expected}' but found '#{actual}'") end |
#visible? ⇒ Boolean
Is UI object visible?
196 197 198 199 200 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 196 def visible? obj, = find_element exists = obj exists ? obj.visible? : false end |
#wait_until_exists(seconds = nil, post_exception = true) ⇒ Object
Wait until the object exists, or until the specified wait time has expired. If the wait time is nil, then the wait time will be Capybara.default_max_wait_time.
265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 265 def wait_until_exists(seconds = nil, post_exception = true) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { exists? } rescue StandardError if post_exception raise "Could not find UI #{} after #{timeout} seconds" unless exists? else exists? end end |
#wait_until_gone(seconds = nil, post_exception = true) ⇒ Object
Wait until the object no longer exists, or until the specified wait time has expired. If the wait time is nil, then the wait time will be Capybara.default_max_wait_time.
284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 284 def wait_until_gone(seconds = nil, post_exception = true) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { !exists? } rescue StandardError if post_exception raise "UI #{} remained visible after #{timeout} seconds" if exists? else exists? end end |
#wait_until_hidden(seconds = nil, post_exception = true) ⇒ Object
Wait until the object is hidden, or until the specified wait time has expired. If the wait time is nil, then the wait time will be Capybara.default_max_wait_time.
322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 322 def wait_until_hidden(seconds = nil, post_exception = true) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { hidden? } rescue StandardError if post_exception raise "UI #{} remained visible after #{timeout} seconds" if visible? else visible? end end |
#wait_until_value_changes(seconds = nil, post_exception = true) ⇒ Object
Wait until the object's value changes to a different value, or until the specified wait time has expired. If the wait time is nil, then the wait time will be Capybara.default_max_wait_time.
363 364 365 366 367 368 369 370 371 372 373 374 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 363 def wait_until_value_changes(seconds = nil, post_exception = true) value = get_value timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { get_value != value } rescue StandardError if post_exception raise "Value of UI #{} failed to change from '#{value}' after #{timeout} seconds" if get_value == value else get_value == value end end |
#wait_until_value_is(value, seconds = nil, post_exception = true) ⇒ Object
Wait until the object's value equals the specified value, or until the specified wait time has expired. If the wait time is nil, then the wait time will be Capybara.default_max_wait_time.
344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 344 def wait_until_value_is(value, seconds = nil, post_exception = true) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { compare(value, get_value) } rescue StandardError if post_exception raise "Value of UI #{} failed to equal '#{value}' after #{timeout} seconds" unless get_value == value else get_value == value end end |
#wait_until_visible(seconds = nil, post_exception = true) ⇒ Object
Wait until the object is visible, or until the specified wait time has expired. If the wait time is nil, then the wait time will be Capybara.default_max_wait_time.
303 304 305 306 307 308 309 310 311 312 313 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 303 def wait_until_visible(seconds = nil, post_exception = true) timeout = seconds.nil? ? Capybara.default_max_wait_time : seconds wait = Selenium::WebDriver::Wait.new(timeout: timeout) wait.until { visible? } rescue StandardError if post_exception raise "Could not find UI #{} after #{timeout} seconds" unless visible? else visible? end end |
#width ⇒ Integer
Return width of object.
398 399 400 401 402 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 398 def width obj, type = find_element(false) object_not_found_exception(obj, type) obj.get_width end |
#x ⇒ Integer
Return x coordinate of object's location.
422 423 424 425 426 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 422 def x obj, type = find_element(false) object_not_found_exception(obj, type) obj.get_x end |
#y ⇒ Integer
Return y coordinate of object's location.
434 435 436 437 438 |
# File 'lib/testcentricity_web/web_elements/ui_elements_helper.rb', line 434 def y obj, type = find_element(false) object_not_found_exception(obj, type) obj.get_y end |